.. image:: https://travis-ci.org/gaomy3832/energydram.svg?branch=master
    :target: https://travis-ci.org/gaomy3832/energydram
.. image:: https://coveralls.io/repos/github/gaomy3832/energydram/badge.svg?branch=master
    :target: https://coveralls.io/github/gaomy3832/energydram?branch=master


DRAM Energy
===========

DRAM energy calculation.


References
----------

Micron, Calculating Memory System Power for DDR3, tech note TN-41-01.

N. Jouppi, A. B. Kahng, N. Muralimanohar and V. Srinivas, CACTI-IO: CACTI With
Off-Chip Power-Area-Timing Models, IEEE Transactions on Very Large Scale
Integration (VLSI) Systems 23(7) (2015), pp. 1254-1267.

